from typing import List, Optional

from pydantic import Field

from ome_types._autogenerated.ome_2016_06.annotation_ref import AnnotationRef
from ome_types._autogenerated.ome_2016_06.detector_type import Detector_Type
from ome_types._autogenerated.ome_2016_06.manufacturer_spec import ManufacturerSpec
from ome_types._autogenerated.ome_2016_06.units_electric_potential import (
    UnitsElectricPotential,
)

__NAMESPACE__ = "http://www.openmicroscopy.org/Schemas/OME/2016-06"


class Detector(ManufacturerSpec):
    """The type of detector used to capture the image.

    The Detector ID can be used as a reference within the Channel
    element in the Image element. The values stored in Detector
    represent the fixed values, variable values modified during the
    acquisition go in DetectorSettings Each attribute now has an
    indication of what type of detector it applies to. This is
    preparatory work for cleaning up and possibly splitting this object
    into sub-types.

    Parameters
    ----------
    annotation_ref:
    gain: The Detector Gain for this detector, as a float. [units:none]
        {used:CCD,EMCCD,PMT}
    voltage: The Voltage of the detector (e.g. PMT voltage) as a float.
        {used:PMT} Units are set by VoltageUnit.
    voltage_unit: The units of the Voltage - default:volts[V].
    offset: The Detector Offset. [units:none] {used:CCD,EMCCD}
    zoom: The fixed Zoom for a detector. [units:none] {used:PMT}
    amplification_gain: Gain applied to the detector signal. This is the
        electronic gain (as apposed to the inherent gain) that is set
        for the detector. [units:none] {used:EMCCD#EMGain}
    id:
    type: The Type of detector. E.g. CCD, PMT, EMCCD etc.
    """

    class Meta:
        namespace = "http://www.openmicroscopy.org/Schemas/OME/2016-06"

    annotation_refs: List[AnnotationRef] = Field(
        default_factory=list,
        metadata={
            "name": "AnnotationRef",
            "type": "Element",
        }
    )
    gain: Optional[float] = Field(
        default=None,
        metadata={
            "name": "Gain",
            "type": "Attribute",
        }
    )
    voltage: Optional[float] = Field(
        default=None,
        metadata={
            "name": "Voltage",
            "type": "Attribute",
        }
    )
    voltage_unit: UnitsElectricPotential = Field(
        default=UnitsElectricPotential.VOLT,
        metadata={
            "name": "VoltageUnit",
            "type": "Attribute",
        }
    )
    offset: Optional[float] = Field(
        default=None,
        metadata={
            "name": "Offset",
            "type": "Attribute",
        }
    )
    zoom: Optional[float] = Field(
        default=None,
        metadata={
            "name": "Zoom",
            "type": "Attribute",
        }
    )
    amplification_gain: Optional[float] = Field(
        default=None,
        metadata={
            "name": "AmplificationGain",
            "type": "Attribute",
        }
    )
    id: str = Field(
        default='__auto_sequence__',
        metadata={
            "name": "ID",
            "type": "Attribute",
            "required": True,
            "pattern": r"(urn:lsid:([\w\-\.]+\.[\w\-\.]+)+:Detector:\S+)|(Detector:\S+)",
        },
        regex="(urn:lsid:([\\w\\-\\.]+\\.[\\w\\-\\.]+)+:Detector:\\S+)|(Detector:\\S+)"
    )
    type: Optional[Detector_Type] = Field(
        default=None,
        metadata={
            "name": "Type",
            "type": "Attribute",
        }
    )


Type = Detector_Type
