from pydantic import Field

from ome_types._autogenerated.ome_2016_06.external_compression import (
    External_Compression,
)
from ome_types._mixins._base_type import OMEType

__NAMESPACE__ = "http://www.openmicroscopy.org/Schemas/OME/2016-06"


class External(OMEType):
    """Describes a file location.

    Can optionally specify a portion of a file using Offset and a
    ReadLength. If Offset and ReadLength are specified in conjuction
    with Compression, then they point into the uncompressed file.

    Parameters
    ----------
    href: file location
    sha1: The digest of the file specified in href.
    compression: Specifies the compression scheme used to encode the
        data.
    """

    class Meta:
        namespace = "http://www.openmicroscopy.org/Schemas/OME/2016-06"

    href: str = Field(
        metadata={
            "type": "Attribute",
            "required": True,
        }
    )
    sha1: bytes = Field(
        metadata={
            "name": "SHA1",
            "type": "Attribute",
            "required": True,
            "length": 20,
            "format": "base16",
        }
    )
    compression: External_Compression = Field(
        default=External_Compression.NONE,
        metadata={
            "name": "Compression",
            "type": "Attribute",
        }
    )


Compression = External_Compression
