from typing import List, Optional

from pydantic import Field

from ome_types._autogenerated.ome_2016_06.annotation_ref import AnnotationRef
from ome_types._autogenerated.ome_2016_06.folder_ref import FolderRef
from ome_types._autogenerated.ome_2016_06.image_ref import ImageRef
from ome_types._autogenerated.ome_2016_06.roi_ref import ROIRef
from ome_types._mixins._base_type import OMEType

__NAMESPACE__ = "http://www.openmicroscopy.org/Schemas/OME/2016-06"


class Folder(OMEType):
    """An element specifying a possibly heterogeneous collection of data.

    Folders may contain Folders so that data may be organized within a
    tree of Folders. Data may be in multiple Folders but a Folder may
    not be in more than one other Folder.

    Parameters
    ----------
    description: A description for the folder. [plain-text multi-line
        string]
    folder_ref:
    image_ref:
    roi_ref:
    annotation_ref:
    id:
    name: A name for the folder that is suitable for presentation to the
        user.
    """

    class Meta:
        namespace = "http://www.openmicroscopy.org/Schemas/OME/2016-06"

    description: Optional[str] = Field(
        default=None,
        metadata={
            "name": "Description",
            "type": "Element",
            "white_space": "preserve",
        }
    )
    folder_refs: List[FolderRef] = Field(
        default_factory=list,
        metadata={
            "name": "FolderRef",
            "type": "Element",
        }
    )
    image_refs: List[ImageRef] = Field(
        default_factory=list,
        metadata={
            "name": "ImageRef",
            "type": "Element",
        }
    )
    roi_refs: List[ROIRef] = Field(
        default_factory=list,
        metadata={
            "name": "ROIRef",
            "type": "Element",
        }
    )
    annotation_refs: List[AnnotationRef] = Field(
        default_factory=list,
        metadata={
            "name": "AnnotationRef",
            "type": "Element",
        }
    )
    id: str = Field(
        default='__auto_sequence__',
        metadata={
            "name": "ID",
            "type": "Attribute",
            "required": True,
            "pattern": r"(urn:lsid:([\w\-\.]+\.[\w\-\.]+)+:Folder:\S+)|(Folder:\S+)",
        },
        regex="(urn:lsid:([\\w\\-\\.]+\\.[\\w\\-\\.]+)+:Folder:\\S+)|(Folder:\\S+)"
    )
    name: Optional[str] = Field(
        default=None,
        metadata={
            "name": "Name",
            "type": "Attribute",
        }
    )
