from typing import List, Optional

from pydantic import Field

from ome_types._autogenerated.ome_2016_06.annotation_ref import AnnotationRef
from ome_types._autogenerated.ome_2016_06.manufacturer_spec import ManufacturerSpec
from ome_types._autogenerated.ome_2016_06.objective_correction import (
    Objective_Correction,
)
from ome_types._autogenerated.ome_2016_06.objective_immersion import Objective_Immersion
from ome_types._autogenerated.ome_2016_06.units_length import UnitsLength

__NAMESPACE__ = "http://www.openmicroscopy.org/Schemas/OME/2016-06"


class Objective(ManufacturerSpec):
    """A description of the microscope's objective lens.

    Required elements include the lens numerical aperture,
    and the magnification, both of which a floating
    point (real) numbers.
    The values are those that are fixed for a particular
    objective: either because it has been manufactured to
    this specification or the value has been measured on
    this particular objective.
    Correction: This is the type of correction coating applied to this lens.
    Immersion: This is the types of immersion medium the lens is designed to
    work with. It is not the same as 'Medium' in ObjectiveRef (a
    single type) as here Immersion can have compound values like 'Multi'.
    LensNA: The numerical aperture of the lens (as a float)
    NominalMagnification: The specified magnification e.g. x10
    CalibratedMagnification: The measured magnification e.g. x10.3
    WorkingDistance: WorkingDistance of the lens.

    Parameters
    ----------
    annotation_ref:
    id:
    correction: The correction applied to the lens
    immersion: The immersion medium the lens is designed for
    lens_na: The numerical aperture of the lens expressed as a floating
        point (real) number. Expected range 0.02 - 1.5 [units:none]
    nominal_magnification: The magnification of the lens as specified by
        the manufacturer - i.e. '60' is a 60X lens. [units:none] Note:
        The type of this has been changed from int to float to allow the
        specification of additional lenses e.g. 0.5X lens
    calibrated_magnification: The magnification of the lens as measured
        by a calibration process- i.e. '59.987' for a 60X lens.
        [units:none]
    working_distance: The working distance of the lens expressed as a
        floating point (real) number. Units are set by
        WorkingDistanceUnit.
    working_distance_unit: The units of the working distance -
        default:microns[µm].
    iris: Records whether or not the objective was fitted with an Iris.
        [flag]
    """

    class Meta:
        namespace = "http://www.openmicroscopy.org/Schemas/OME/2016-06"

    annotation_refs: List[AnnotationRef] = Field(
        default_factory=list,
        metadata={
            "name": "AnnotationRef",
            "type": "Element",
        }
    )
    id: str = Field(
        default='__auto_sequence__',
        metadata={
            "name": "ID",
            "type": "Attribute",
            "required": True,
            "pattern": r"(urn:lsid:([\w\-\.]+\.[\w\-\.]+)+:Objective:\S+)|(Objective:\S+)",
        },
        regex="(urn:lsid:([\\w\\-\\.]+\\.[\\w\\-\\.]+)+:Objective:\\S+)|(Objective:\\S+)"
    )
    correction: Optional[Objective_Correction] = Field(
        default=None,
        metadata={
            "name": "Correction",
            "type": "Attribute",
        }
    )
    immersion: Optional[Objective_Immersion] = Field(
        default=None,
        metadata={
            "name": "Immersion",
            "type": "Attribute",
        }
    )
    lens_na: Optional[float] = Field(
        default=None,
        metadata={
            "name": "LensNA",
            "type": "Attribute",
        }
    )
    nominal_magnification: Optional[float] = Field(
        default=None,
        metadata={
            "name": "NominalMagnification",
            "type": "Attribute",
        }
    )
    calibrated_magnification: Optional[float] = Field(
        default=None,
        metadata={
            "name": "CalibratedMagnification",
            "type": "Attribute",
        }
    )
    working_distance: Optional[float] = Field(
        default=None,
        metadata={
            "name": "WorkingDistance",
            "type": "Attribute",
        }
    )
    working_distance_unit: UnitsLength = Field(
        default=UnitsLength.MICROMETER,
        metadata={
            "name": "WorkingDistanceUnit",
            "type": "Attribute",
        }
    )
    iris: Optional[bool] = Field(
        default=None,
        metadata={
            "name": "Iris",
            "type": "Attribute",
        }
    )


Correction = Objective_Correction
Immersion = Objective_Immersion
