from typing import Optional

from pydantic import Field

from ome_types._autogenerated.ome_2016_06.objective_settings_medium import (
    ObjectiveSettings_Medium,
)
from ome_types._autogenerated.ome_2016_06.settings import Settings

__NAMESPACE__ = "http://www.openmicroscopy.org/Schemas/OME/2016-06"


class ObjectiveSettings(Settings):
    """This holds the setting applied to an objective as well as a reference to the
    objective.

    The ID is the objective used in this case.

    Parameters
    ----------
    id:
    correction_collar: The CorrectionCollar is normally an adjustable
        ring on the objective. Each has an arbitrary scale on it so the
        values is unit-less. [units:none]
    medium:
    refractive_index: The RefractiveIndex is that of the immersion
        medium. This is a ratio so it also unit-less. [units:none]
    """

    class Meta:
        namespace = "http://www.openmicroscopy.org/Schemas/OME/2016-06"

    id: str = Field(
        default='__auto_sequence__',
        metadata={
            "name": "ID",
            "type": "Attribute",
            "required": True,
            "pattern": r"(urn:lsid:([\w\-\.]+\.[\w\-\.]+)+:Objective:\S+)|(Objective:\S+)",
        },
        regex="(urn:lsid:([\\w\\-\\.]+\\.[\\w\\-\\.]+)+:Objective:\\S+)|(Objective:\\S+)"
    )
    correction_collar: Optional[float] = Field(
        default=None,
        metadata={
            "name": "CorrectionCollar",
            "type": "Attribute",
        }
    )
    medium: Optional[ObjectiveSettings_Medium] = Field(
        default=None,
        metadata={
            "name": "Medium",
            "type": "Attribute",
        }
    )
    refractive_index: Optional[float] = Field(
        default=None,
        metadata={
            "name": "RefractiveIndex",
            "type": "Attribute",
        }
    )


Medium = ObjectiveSettings_Medium
