from typing import List, Optional

from pydantic import Field

from ome_types._autogenerated.ome_2016_06.dataset import Dataset
from ome_types._autogenerated.ome_2016_06.experiment import Experiment
from ome_types._autogenerated.ome_2016_06.experimenter import Experimenter
from ome_types._autogenerated.ome_2016_06.experimenter_group import ExperimenterGroup
from ome_types._autogenerated.ome_2016_06.folder import Folder
from ome_types._autogenerated.ome_2016_06.image import Image
from ome_types._autogenerated.ome_2016_06.instrument import Instrument
from ome_types._autogenerated.ome_2016_06.plate import Plate
from ome_types._autogenerated.ome_2016_06.project import Project
from ome_types._autogenerated.ome_2016_06.rights import Rights
from ome_types._autogenerated.ome_2016_06.roi import ROI
from ome_types._autogenerated.ome_2016_06.screen import Screen
from ome_types._mixins._base_type import OMEType
from ome_types._mixins._ome import OMEMixin
from ome_types.model._structured_annotations import StructuredAnnotationList

__NAMESPACE__ = "http://www.openmicroscopy.org/Schemas/OME/2016-06"


class OME(OMEMixin, OMEType):
    """The OME element is a container for all information objects accessible by
    OME.

    These information objects include descriptions of the imaging experiments
    and the people who perform them, descriptions of the microscope, the resulting
    images and how they were acquired, the analyses performed on those images,
    and the analysis results themselves.
    An OME file may contain any or all of this information.
    With the creation of the Metadata Only Companion OME-XML and Binary Only OME-TIFF files
    the top level OME node has changed slightly.
    It can EITHER:
    Contain all the previously expected elements
    OR:
    Contain a single BinaryOnly element that points at
    its Metadata Only Companion OME-XML file.

    Parameters
    ----------
    rights:
    project:
    dataset:
    folder:
    experiment:
    plate:
    screen:
    experimenter:
    experimenter_group:
    instrument:
    image:
    structured_annotations:
    roi:
    binary_only: Pointer to an external metadata file. If this element
        is present, then no other metadata may be present in this file,
        i.e. this file is a place-holder.
    uuid: This unique identifier is used to keep track of multi part
        files. It allows the links between files to survive renaming.
        While OPTIONAL in the general case this is REQUIRED in a
        MetadataOnly Companion to a collection of BinaryOnly files.
    creator: This is the name of the creating application of the OME-XML
        and preferably its full version. e.g "CompanyName, SoftwareName,
        V2.6.3456" This is optional but we hope it will be set by
        applications writing out OME-XML from scratch.
    """

    class Meta:
        namespace = "http://www.openmicroscopy.org/Schemas/OME/2016-06"

    rights: Optional[Rights] = Field(
        default=None,
        metadata={
            "name": "Rights",
            "type": "Element",
        }
    )
    projects: List[Project] = Field(
        default_factory=list,
        metadata={
            "name": "Project",
            "type": "Element",
        }
    )
    datasets: List[Dataset] = Field(
        default_factory=list,
        metadata={
            "name": "Dataset",
            "type": "Element",
        }
    )
    folders: List[Folder] = Field(
        default_factory=list,
        metadata={
            "name": "Folder",
            "type": "Element",
        }
    )
    experiments: List[Experiment] = Field(
        default_factory=list,
        metadata={
            "name": "Experiment",
            "type": "Element",
        }
    )
    plates: List[Plate] = Field(
        default_factory=list,
        metadata={
            "name": "Plate",
            "type": "Element",
        }
    )
    screens: List[Screen] = Field(
        default_factory=list,
        metadata={
            "name": "Screen",
            "type": "Element",
        }
    )
    experimenters: List[Experimenter] = Field(
        default_factory=list,
        metadata={
            "name": "Experimenter",
            "type": "Element",
        }
    )
    experimenter_groups: List[ExperimenterGroup] = Field(
        default_factory=list,
        metadata={
            "name": "ExperimenterGroup",
            "type": "Element",
        }
    )
    instruments: List[Instrument] = Field(
        default_factory=list,
        metadata={
            "name": "Instrument",
            "type": "Element",
        }
    )
    images: List[Image] = Field(
        default_factory=list,
        metadata={
            "name": "Image",
            "type": "Element",
        }
    )
    structured_annotations: StructuredAnnotationList = Field(
        default_factory=StructuredAnnotationList,
        metadata={
            "name": "StructuredAnnotations",
            "type": "Element",
        }
    )
    rois: List[ROI] = Field(
        default_factory=list,
        metadata={
            "name": "ROI",
            "type": "Element",
        }
    )
    binary_only: Optional["OME.BinaryOnly"] = Field(
        default=None,
        metadata={
            "name": "BinaryOnly",
            "type": "Element",
        }
    )
    uuid: Optional[str] = Field(
        default=None,
        metadata={
            "name": "UUID",
            "type": "Attribute",
            "pattern": r"(urn:uuid:[0-9a-fA-F]{8}-[0-9a-fA-F]{4}-[0-9a-fA-F]{4}-[0-9a-fA-F]{4}-[0-9a-fA-F]{12})",
        },
        regex="(urn:uuid:[0-9a-fA-F]{8}-[0-9a-fA-F]{4}-[0-9a-fA-F]{4}-[0-9a-fA-F]{4}-[0-9a-fA-F]{12})"
    )
    creator: Optional[str] = Field(
        default=None,
        metadata={
            "name": "Creator",
            "type": "Attribute",
        }
    )


    class BinaryOnly(OMEType):
        """
        Parameters
        ----------
        metadata_file: Filename of the OME-XML metadata file for this
            binary data. If the file cannot be found, a search can be
            performed based on the UUID.
        uuid: The unique identifier of another OME-XML block whose
            metadata describes the binary data in this file. This UUID
            is considered authoritative regardless of mismatches in the
            filename.
        """

        metadata_file: str = Field(
            metadata={
                "name": "MetadataFile",
                "type": "Attribute",
                "required": True,
            }
        )
        uuid: str = Field(
            metadata={
                "name": "UUID",
                "type": "Attribute",
                "required": True,
                "pattern": r"(urn:uuid:[0-9a-fA-F]{8}-[0-9a-fA-F]{4}-[0-9a-fA-F]{4}-[0-9a-fA-F]{4}-[0-9a-fA-F]{12})",
            },
            regex="(urn:uuid:[0-9a-fA-F]{8}-[0-9a-fA-F]{4}-[0-9a-fA-F]{4}-[0-9a-fA-F]{4}-[0-9a-fA-F]{12})"
        )


BinaryOnly = OME.BinaryOnly
