from typing import List, Optional

from pydantic import Field

from ome_types._autogenerated.ome_2016_06.annotation_ref import AnnotationRef
from ome_types._autogenerated.ome_2016_06.units_length import UnitsLength
from ome_types._autogenerated.ome_2016_06.units_time import UnitsTime
from ome_types._mixins._base_type import OMEType

__NAMESPACE__ = "http://www.openmicroscopy.org/Schemas/OME/2016-06"


class Plane(OMEType):
    """
    The Plane object holds microscope stage and image timing data for a given
    channel/z-section/timepoint.

    Parameters
    ----------
    hash_sha1:
    annotation_ref:
    the_z: The Z-section this plane is for. [units:none] This is
        numbered from 0.
    the_t: The timepoint this plane is for. [units:none] This is
        numbered from 0.
    the_c: The channel this plane is for. [units:none] This is numbered
        from 0.
    delta_t: Time since the beginning of the experiment. Units are set
        by DeltaTUnit.
    delta_t_unit: The units of the DeltaT - default:seconds[s].
    exposure_time: The length of the exposure. Units are set by
        ExposureTimeUnit.
    exposure_time_unit: The units of the ExposureTime -
        default:seconds[s].
    position_x: The X position of the stage. Units are set by
        PositionXUnit.
    position_x_unit: The units of the X stage position -
        default:[reference frame].
    position_y: The Y position of the stage. Units are set by
        PositionYUnit.
    position_y_unit: The units of the Y stage position -
        default:[reference frame].
    position_z: The Z position of the stage. Units are set by
        PositionZUnit.
    position_z_unit: The units of the Z stage position -
        default:[reference frame].
    """

    class Meta:
        namespace = "http://www.openmicroscopy.org/Schemas/OME/2016-06"

    hash_sha1: Optional[bytes] = Field(
        default=None,
        metadata={
            "name": "HashSHA1",
            "type": "Element",
            "length": 20,
            "format": "base16",
        }
    )
    annotation_refs: List[AnnotationRef] = Field(
        default_factory=list,
        metadata={
            "name": "AnnotationRef",
            "type": "Element",
        }
    )
    the_z: int = Field(
        metadata={
            "name": "TheZ",
            "type": "Attribute",
            "required": True,
            "min_inclusive": 0,
        },
        ge=0
    )
    the_t: int = Field(
        metadata={
            "name": "TheT",
            "type": "Attribute",
            "required": True,
            "min_inclusive": 0,
        },
        ge=0
    )
    the_c: int = Field(
        metadata={
            "name": "TheC",
            "type": "Attribute",
            "required": True,
            "min_inclusive": 0,
        },
        ge=0
    )
    delta_t: Optional[float] = Field(
        default=None,
        metadata={
            "name": "DeltaT",
            "type": "Attribute",
        }
    )
    delta_t_unit: UnitsTime = Field(
        default=UnitsTime.SECOND,
        metadata={
            "name": "DeltaTUnit",
            "type": "Attribute",
        }
    )
    exposure_time: Optional[float] = Field(
        default=None,
        metadata={
            "name": "ExposureTime",
            "type": "Attribute",
        }
    )
    exposure_time_unit: UnitsTime = Field(
        default=UnitsTime.SECOND,
        metadata={
            "name": "ExposureTimeUnit",
            "type": "Attribute",
        }
    )
    position_x: Optional[float] = Field(
        default=None,
        metadata={
            "name": "PositionX",
            "type": "Attribute",
        }
    )
    position_x_unit: UnitsLength = Field(
        default=UnitsLength.REFERENCEFRAME,
        metadata={
            "name": "PositionXUnit",
            "type": "Attribute",
        }
    )
    position_y: Optional[float] = Field(
        default=None,
        metadata={
            "name": "PositionY",
            "type": "Attribute",
        }
    )
    position_y_unit: UnitsLength = Field(
        default=UnitsLength.REFERENCEFRAME,
        metadata={
            "name": "PositionYUnit",
            "type": "Attribute",
        }
    )
    position_z: Optional[float] = Field(
        default=None,
        metadata={
            "name": "PositionZ",
            "type": "Attribute",
        }
    )
    position_z_unit: UnitsLength = Field(
        default=UnitsLength.REFERENCEFRAME,
        metadata={
            "name": "PositionZUnit",
            "type": "Attribute",
        }
    )
