from typing import List, Optional

from pydantic import Field

from ome_types._autogenerated.ome_2016_06.annotation_ref import AnnotationRef
from ome_types._mixins._base_type import OMEType

__NAMESPACE__ = "http://www.openmicroscopy.org/Schemas/OME/2016-06"


class Reagent(OMEType):
    """
    Reagent is used to describe a chemical or some other physical experimental
    parameter.

    Parameters
    ----------
    description: A long description for the reagent.
    annotation_ref:
    id:
    name: A short name for the reagent
    reagent_identifier: This is a reference to an external (to OME)
        representation of the Reagent. It serves as a foreign key into
        an external database. - It is sometimes referred to as
        ExternalIdentifier.
    """

    class Meta:
        namespace = "http://www.openmicroscopy.org/Schemas/OME/2016-06"

    description: Optional[str] = Field(
        default=None,
        metadata={
            "name": "Description",
            "type": "Element",
            "white_space": "preserve",
        }
    )
    annotation_refs: List[AnnotationRef] = Field(
        default_factory=list,
        metadata={
            "name": "AnnotationRef",
            "type": "Element",
        }
    )
    id: str = Field(
        default='__auto_sequence__',
        metadata={
            "name": "ID",
            "type": "Attribute",
            "required": True,
            "pattern": r"(urn:lsid:([\w\-\.]+\.[\w\-\.]+)+:Reagent:\S+)|(Reagent:\S+)",
        },
        regex="(urn:lsid:([\\w\\-\\.]+\\.[\\w\\-\\.]+)+:Reagent:\\S+)|(Reagent:\\S+)"
    )
    name: Optional[str] = Field(
        default=None,
        metadata={
            "name": "Name",
            "type": "Attribute",
        }
    )
    reagent_identifier: Optional[str] = Field(
        default=None,
        metadata={
            "name": "ReagentIdentifier",
            "type": "Attribute",
        }
    )
