from typing import List, Optional

from pydantic import Field

from ome_types._autogenerated.ome_2016_06.affine_transform import AffineTransform
from ome_types._autogenerated.ome_2016_06.annotation_ref import AnnotationRef
from ome_types._autogenerated.ome_2016_06.shape_fill_rule import Shape_FillRule
from ome_types._autogenerated.ome_2016_06.shape_font_family import Shape_FontFamily
from ome_types._autogenerated.ome_2016_06.shape_font_style import Shape_FontStyle
from ome_types._autogenerated.ome_2016_06.units_length import UnitsLength
from ome_types._mixins._base_type import OMEType

__NAMESPACE__ = "http://www.openmicroscopy.org/Schemas/OME/2016-06"


class Shape(OMEType):
    """The shape element contains a single specific ROI shape and links that to any
    channels, and a timepoint and a z-section.

    It also records any transform applied to the ROI shape.

    Parameters
    ----------
    transform: This is a matrix used to transform the shape. The element
        has 6 xsd:float attributes. If the element is present then all 6
        values must be included.
    annotation_ref:
    fill_color: The color of the fill - encoded as RGBA The value "-1"
        is #FFFFFFFF so solid white (it is a signed 32 bit value) NOTE:
        Prior to the 2012-06 schema the default value was incorrect and
        produced a transparent red not solid white.
    fill_rule:
    stroke_color: The color of the stroke  - encoded as RGBA The value
        "-1" is #FFFFFFFF so solid white (it is a signed 32 bit value)
        NOTE: Prior to the 2012-06 schema the default value was
        incorrect and produced a transparent red not solid white.
    stroke_width: The width of the stroke. Units are set by
        StrokeWidthUnit.
    stroke_width_unit: The units used for the stroke width.
    stroke_dash_array: e.g. "none", "10 20 30 10"
    text:
    font_family:
    font_size: Size of the font. Units are set by FontSizeUnit.
    font_size_unit: The units used for the font size.
    font_style:
    locked: Controls whether the shape is locked and read only, true is
        locked, false is editable.
    id:
    the_z: The z-section the ROI applies to. If not specified then the
        ROI applies to all the z-sections of the image. [units:none]
        This is numbered from 0.
    the_t: The timepoint the ROI applies to. If not specified then the
        ROI applies to all the timepoints of the image. [units:none]
        This is numbered from 0.
    the_c: The channel the ROI applies to. If not specified then the ROI
        applies to all the channels of the image. [units:none] This is
        numbered from 0.
    """

    transform: Optional[AffineTransform] = Field(
        default=None,
        metadata={
            "name": "Transform",
            "type": "Element",
            "namespace": "http://www.openmicroscopy.org/Schemas/OME/2016-06",
        }
    )
    annotation_refs: List[AnnotationRef] = Field(
        default_factory=list,
        metadata={
            "name": "AnnotationRef",
            "type": "Element",
            "namespace": "http://www.openmicroscopy.org/Schemas/OME/2016-06",
        }
    )
    fill_color: Optional[int] = Field(
        default=None,
        metadata={
            "name": "FillColor",
            "type": "Attribute",
        }
    )
    fill_rule: Optional[Shape_FillRule] = Field(
        default=None,
        metadata={
            "name": "FillRule",
            "type": "Attribute",
        }
    )
    stroke_color: Optional[int] = Field(
        default=None,
        metadata={
            "name": "StrokeColor",
            "type": "Attribute",
        }
    )
    stroke_width: Optional[float] = Field(
        default=None,
        metadata={
            "name": "StrokeWidth",
            "type": "Attribute",
        }
    )
    stroke_width_unit: UnitsLength = Field(
        default=UnitsLength.PIXEL,
        metadata={
            "name": "StrokeWidthUnit",
            "type": "Attribute",
        }
    )
    stroke_dash_array: Optional[str] = Field(
        default=None,
        metadata={
            "name": "StrokeDashArray",
            "type": "Attribute",
        }
    )
    text: Optional[str] = Field(
        default=None,
        metadata={
            "name": "Text",
            "type": "Attribute",
        }
    )
    font_family: Optional[Shape_FontFamily] = Field(
        default=None,
        metadata={
            "name": "FontFamily",
            "type": "Attribute",
        }
    )
    font_size: Optional[int] = Field(
        default=None,
        metadata={
            "name": "FontSize",
            "type": "Attribute",
            "min_inclusive": 0,
        },
        ge=0
    )
    font_size_unit: UnitsLength = Field(
        default=UnitsLength.POINT,
        metadata={
            "name": "FontSizeUnit",
            "type": "Attribute",
        }
    )
    font_style: Optional[Shape_FontStyle] = Field(
        default=None,
        metadata={
            "name": "FontStyle",
            "type": "Attribute",
        }
    )
    locked: Optional[bool] = Field(
        default=None,
        metadata={
            "name": "Locked",
            "type": "Attribute",
        }
    )
    id: str = Field(
        default='__auto_sequence__',
        metadata={
            "name": "ID",
            "type": "Attribute",
            "required": True,
            "pattern": r"(urn:lsid:([\w\-\.]+\.[\w\-\.]+)+:Shape:\S+)|(Shape:\S+)",
        },
        regex="(urn:lsid:([\\w\\-\\.]+\\.[\\w\\-\\.]+)+:Shape:\\S+)|(Shape:\\S+)"
    )
    the_z: Optional[int] = Field(
        default=None,
        metadata={
            "name": "TheZ",
            "type": "Attribute",
            "min_inclusive": 0,
        },
        ge=0
    )
    the_t: Optional[int] = Field(
        default=None,
        metadata={
            "name": "TheT",
            "type": "Attribute",
            "min_inclusive": 0,
        },
        ge=0
    )
    the_c: Optional[int] = Field(
        default=None,
        metadata={
            "name": "TheC",
            "type": "Attribute",
            "min_inclusive": 0,
        },
        ge=0
    )


FillRule = Shape_FillRule
FontFamily = Shape_FontFamily
FontStyle = Shape_FontStyle
