from typing import List, Optional

from pydantic import Field

from ome_types._autogenerated.ome_2016_06.annotation_ref import AnnotationRef
from ome_types._autogenerated.ome_2016_06.reagent_ref import ReagentRef
from ome_types._autogenerated.ome_2016_06.well_sample import WellSample
from ome_types._mixins._base_type import OMEType
from ome_types.model._color import Color

__NAMESPACE__ = "http://www.openmicroscopy.org/Schemas/OME/2016-06"


class Well(OMEType):
    """A Well is a component of the Well/Plate/Screen construct to describe
    screening applications.

    A Well has a number of WellSample elements that link to the Images
    collected in this well. The ReagentRef links any Reagents that were
    used in this Well. A well is part of only one Plate. The origin for
    the row and column identifiers is the top left corner of the plate
    starting at zero. i.e The top left well of a plate is index (0,0)

    Parameters
    ----------
    well_sample:
    reagent_ref:
    annotation_ref:
    id:
    column: This is the column index of the well, the origin is the top
        left corner of the plate with the first column of cells being
        column zero. i.e top left is (0,0) The combination of Row,
        Column has to be unique for each well in a plate.
    row: This is the row index of the well, the origin is the top left
        corner of the plate with the first row of wells being row zero.
        i.e top left is (0,0) The combination of Row, Column has to be
        unique for each well in a plate.
    external_description: A description of the externally defined
        identifier for this plate.
    external_identifier: The ExternalIdentifier attribute may contain a
        reference to an external database.
    type: A human readable identifier for the screening status. e.g.
        empty, positive control, negative control, control,
        experimental, etc.
    color: A marker color used to highlight the well - encoded as RGBA
        The default value "-1" is #FFFFFFFF so solid white (it is a
        signed 32 bit value) NOTE: Prior to the 2012-06 schema the
        default value was incorrect and produced a transparent red not
        solid white.
    """

    class Meta:
        namespace = "http://www.openmicroscopy.org/Schemas/OME/2016-06"

    well_samples: List[WellSample] = Field(
        default_factory=list,
        metadata={
            "name": "WellSample",
            "type": "Element",
        }
    )
    reagent_ref: Optional[ReagentRef] = Field(
        default=None,
        metadata={
            "name": "ReagentRef",
            "type": "Element",
        }
    )
    annotation_refs: List[AnnotationRef] = Field(
        default_factory=list,
        metadata={
            "name": "AnnotationRef",
            "type": "Element",
        }
    )
    id: str = Field(
        default='__auto_sequence__',
        metadata={
            "name": "ID",
            "type": "Attribute",
            "required": True,
            "pattern": r"(urn:lsid:([\w\-\.]+\.[\w\-\.]+)+:Well:\S+)|(Well:\S+)",
        },
        regex="(urn:lsid:([\\w\\-\\.]+\\.[\\w\\-\\.]+)+:Well:\\S+)|(Well:\\S+)"
    )
    column: int = Field(
        metadata={
            "name": "Column",
            "type": "Attribute",
            "required": True,
            "min_inclusive": 0,
        },
        ge=0
    )
    row: int = Field(
        metadata={
            "name": "Row",
            "type": "Attribute",
            "required": True,
            "min_inclusive": 0,
        },
        ge=0
    )
    external_description: Optional[str] = Field(
        default=None,
        metadata={
            "name": "ExternalDescription",
            "type": "Attribute",
        }
    )
    external_identifier: Optional[str] = Field(
        default=None,
        metadata={
            "name": "ExternalIdentifier",
            "type": "Attribute",
        }
    )
    type: Optional[str] = Field(
        default=None,
        metadata={
            "name": "Type",
            "type": "Attribute",
        }
    )
    color: Color = Field(
        default_factory=Color,
        metadata={
            "name": "Color",
            "type": "Attribute",
        }
    )
